@@ -1,5 +1,7 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
+
 """
 Astroid hook for the Hypothesis library.
 
@@ -13,10 +15,9 @@ defined using the `@hypothesis.strategies.composite` decorator.  For example:
         return draw(st.integers())
 
     a_strategy()
-
 """
 from astroid.manager import AstroidManager
-from astroid.scoped_nodes import FunctionDef
+from astroid.nodes.scoped_nodes import FunctionDef
 
 COMPOSITE_NAMES = (
     "composite",
@@ -26,8 +27,8 @@ COMPOSITE_NAMES = (
 )
 
 
-def is_decorated_with_st_composite(node):
-    """Return True if a decorated node has @st.composite applied."""
+def is_decorated_with_st_composite(node: FunctionDef) -> bool:
+    """Return whether a decorated node has @st.composite applied."""
     if node.decorators and node.args.args and node.args.args[0].name == "draw":
         for decorator_attribute in node.decorators.nodes:
             if decorator_attribute.as_string() in COMPOSITE_NAMES:
@@ -35,19 +36,21 @@ def is_decorated_with_st_composite(node):
     return False
 
 
-def remove_draw_parameter_from_composite_strategy(node):
+def remove_draw_parameter_from_composite_strategy(node: FunctionDef) -> FunctionDef:
     """Given that the FunctionDef is decorated with @st.composite, remove the
     first argument (`draw`) - it's always supplied by Hypothesis so we don't
     need to emit the no-value-for-parameter lint.
     """
+    assert isinstance(node.args.args, list)
     del node.args.args[0]
     del node.args.annotations[0]
     del node.args.type_comment_args[0]
     return node
 
 
-AstroidManager().register_transform(
-    node_class=FunctionDef,
-    transform=remove_draw_parameter_from_composite_strategy,
-    predicate=is_decorated_with_st_composite,
-)
+def register(manager: AstroidManager) -> None:
+    manager.register_transform(
+        node_class=FunctionDef,
+        transform=remove_draw_parameter_from_composite_strategy,
+        predicate=is_decorated_with_st_composite,
+    )
