@@ -1,21 +1,27 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 """Astroid hooks for the PyQT library."""
 
-from astroid import nodes, parse
+from astroid import nodes
 from astroid.brain.helpers import register_module_extender
-from astroid.builder import AstroidBuilder
+from astroid.builder import AstroidBuilder, parse
 from astroid.manager import AstroidManager
 
 
-def _looks_like_signal(node, signal_name="pyqtSignal"):
-    if "__class__" in node.instance_attrs:
+def _looks_like_signal(
+    node: nodes.FunctionDef, signal_name: str = "pyqtSignal"
+) -> bool:
+    """Detect a Signal node."""
+    klasses = node.instance_attrs.get("__class__", [])
+    # On PySide2 or PySide6 (since  Qt 5.15.2) the Signal class changed locations
+    if node.qname().partition(".")[0] in {"PySide2", "PySide6"}:
+        return any(cls.qname() == "Signal" for cls in klasses)  # pragma: no cover
+    if klasses:
         try:
-            cls = node.instance_attrs["__class__"][0]
-            return cls.name == signal_name
-        except AttributeError:
+            return klasses[0].name == signal_name
+        except AttributeError:  # pragma: no cover
             # return False if the cls does not have a name attribute
             pass
     return False
@@ -71,12 +77,13 @@ class QObject(object):
     )
 
 
-register_module_extender(AstroidManager(), "PyQt4.QtCore", pyqt4_qtcore_transform)
-AstroidManager().register_transform(
-    nodes.FunctionDef, transform_pyqt_signal, _looks_like_signal
-)
-AstroidManager().register_transform(
-    nodes.ClassDef,
-    transform_pyside_signal,
-    lambda node: node.qname() in {"PySide.QtCore.Signal", "PySide2.QtCore.Signal"},
-)
+def register(manager: AstroidManager) -> None:
+    register_module_extender(manager, "PyQt4.QtCore", pyqt4_qtcore_transform)
+    manager.register_transform(
+        nodes.FunctionDef, transform_pyqt_signal, _looks_like_signal
+    )
+    manager.register_transform(
+        nodes.ClassDef,
+        transform_pyside_signal,
+        lambda node: node.qname() in {"PySide.QtCore.Signal", "PySide2.QtCore.Signal"},
+    )
