@@ -18,10 +18,7 @@ import zipimport
 from collections.abc import Iterable, Iterator, Sequence
 from functools import lru_cache
 from pathlib import Path
-from typing import Any, Literal, NamedTuple, Protocol
-
-from astroid.const import PY310_PLUS
-from astroid.modutils import EXT_LIB_DIRS
+from typing import Literal, NamedTuple, Protocol
 
 from . import util
 
@@ -86,13 +83,13 @@ class Finder:
     def __init__(self, path: Sequence[str] | None = None) -> None:
         self._path = path or sys.path
 
+    @staticmethod
     @abc.abstractmethod
     def find_module(
-        self,
         modname: str,
-        module_parts: Sequence[str],
-        processed: list[str],
-        submodule_path: Sequence[str] | None,
+        module_parts: tuple[str, ...],
+        processed: tuple[str, ...],
+        submodule_path: tuple[str, ...] | None,
     ) -> ModuleSpec | None:
         """Find the given module.
 
@@ -100,12 +97,12 @@ class Finder:
         they all return a ModuleSpec.
 
         :param modname: The module which needs to be searched.
-        :param module_parts: It should be a list of strings,
+        :param module_parts: It should be a tuple of strings,
                                   where each part contributes to the module's
                                   namespace.
         :param processed: What parts from the module parts were processed
                                so far.
-        :param submodule_path: A list of paths where the module
+        :param submodule_path: A tuple of paths where the module
                                     can be looked into.
         :returns: A ModuleSpec, describing how and where the module was found,
                   None, otherwise.
@@ -126,13 +123,17 @@ class ImportlibFinder(Finder):
         + [(s, ModuleType.PY_COMPILED) for s in importlib.machinery.BYTECODE_SUFFIXES]
     )
 
+    @staticmethod
+    @lru_cache(maxsize=1024)
     def find_module(
-        self,
         modname: str,
-        module_parts: Sequence[str],
-        processed: list[str],
-        submodule_path: Sequence[str] | None,
+        module_parts: tuple[str, ...],
+        processed: tuple[str, ...],
+        submodule_path: tuple[str, ...] | None,
     ) -> ModuleSpec | None:
+        # pylint: disable-next=import-outside-toplevel
+        from astroid.modutils import cached_os_path_isfile
+
         # Although we should be able to use `find_spec` this doesn't work on PyPy for builtins.
         # Therefore, we use the `builtin_module_nams` heuristic for these.
         if submodule_path is None and modname in sys.builtin_module_names:
@@ -153,7 +154,7 @@ class ImportlibFinder(Finder):
             for suffix in suffixes:
                 package_file_name = "__init__" + suffix
                 file_path = os.path.join(package_directory, package_file_name)
-                if os.path.isfile(file_path):
+                if cached_os_path_isfile(file_path):
                     return ModuleSpec(
                         name=modname,
                         location=package_directory,
@@ -162,59 +163,33 @@ class ImportlibFinder(Finder):
             for suffix, type_ in ImportlibFinder._SUFFIXES:
                 file_name = modname + suffix
                 file_path = os.path.join(entry, file_name)
-                if os.path.isfile(file_path):
+                if cached_os_path_isfile(file_path):
                     return ModuleSpec(name=modname, location=file_path, type=type_)
 
-        # sys.stdlib_module_names was added in Python 3.10
-        if PY310_PLUS:
-            # If the module name matches a stdlib module name, check whether this is a frozen
-            # module. Note that `find_spec` actually imports parent modules, so we want to make
-            # sure we only run this code for stuff that can be expected to be frozen. For now
-            # this is only stdlib.
-            if modname in sys.stdlib_module_names or (
-                processed and processed[0] in sys.stdlib_module_names
-            ):
-                try:
-                    with warnings.catch_warnings():
-                        warnings.filterwarnings("ignore", category=Warning)
-                        spec = importlib.util.find_spec(".".join((*processed, modname)))
-                except ValueError:
-                    spec = None
+        # If the module name matches a stdlib module name, check whether this is a frozen
+        # module. Note that `find_spec` actually imports parent modules, so we want to make
+        # sure we only run this code for stuff that can be expected to be frozen. For now
+        # this is only stdlib.
+        if (modname in sys.stdlib_module_names and not processed) or (
+            processed and processed[0] in sys.stdlib_module_names
+        ):
+            try:
+                with warnings.catch_warnings():
+                    warnings.filterwarnings("ignore", category=Warning)
+                    spec = importlib.util.find_spec(".".join((*processed, modname)))
+            except ValueError:
+                spec = None
 
-                if (
-                    spec
-                    and spec.loader  # type: ignore[comparison-overlap] # noqa: E501
-                    is importlib.machinery.FrozenImporter
-                ):
-                    return ModuleSpec(
-                        name=modname,
-                        location=getattr(spec.loader_state, "filename", None),
-                        type=ModuleType.PY_FROZEN,
-                    )
-        else:
-            # NOTE: This is broken code. It doesn't work on Python 3.13+ where submodules can also
-            # be frozen. However, we don't want to worry about this and we don't want to break
-            # support for older versions of Python. This is just copy-pasted from the old non
-            # working version to at least have no functional behaviour change on <=3.10.
-            # It can be removed after 3.10 is no longer supported in favour of the logic above.
-            if submodule_path is None:  # pylint: disable=else-if-used
-                try:
-                    with warnings.catch_warnings():
-                        warnings.filterwarnings("ignore", category=UserWarning)
-                        spec = importlib.util.find_spec(modname)
-                    if (
-                        spec
-                        and spec.loader  # type: ignore[comparison-overlap] # noqa: E501
-                        is importlib.machinery.FrozenImporter
-                    ):
-                        # No need for BuiltinImporter; builtins handled above
-                        return ModuleSpec(
-                            name=modname,
-                            location=getattr(spec.loader_state, "filename", None),
-                            type=ModuleType.PY_FROZEN,
-                        )
-                except ValueError:
-                    pass
+            if (
+                spec
+                and spec.loader  # type: ignore[comparison-overlap] # noqa: E501
+                is importlib.machinery.FrozenImporter
+            ):
+                return ModuleSpec(
+                    name=modname,
+                    location=getattr(spec.loader_state, "filename", None),
+                    type=ModuleType.PY_FROZEN,
+                )
 
         return None
 
@@ -224,6 +199,8 @@ class ImportlibFinder(Finder):
         if spec.location is None:
             # Builtin.
             return None
+        # pylint: disable-next=import-outside-toplevel
+        from astroid.modutils import EXT_LIB_DIRS
 
         if _is_setuptools_namespace(Path(spec.location)):
             # extend_path is called, search sys.path for module/packages
@@ -259,12 +236,13 @@ class ImportlibFinder(Finder):
 class ExplicitNamespacePackageFinder(ImportlibFinder):
     """A finder for the explicit namespace packages."""
 
+    @staticmethod
+    @lru_cache(maxsize=1024)
     def find_module(
-        self,
         modname: str,
-        module_parts: Sequence[str],
-        processed: list[str],
-        submodule_path: Sequence[str] | None,
+        module_parts: tuple[str, ...],
+        processed: tuple[str, ...],
+        submodule_path: tuple[str, ...] | None,
     ) -> ModuleSpec | None:
         if processed:
             modname = ".".join([*processed, modname])
@@ -292,18 +270,19 @@ class ZipFinder(Finder):
         for entry_path in path:
             if entry_path not in sys.path_importer_cache:
                 try:
-                    sys.path_importer_cache[entry_path] = zipimport.zipimporter(  # type: ignore[assignment]
+                    sys.path_importer_cache[entry_path] = zipimport.zipimporter(
                         entry_path
                     )
                 except zipimport.ZipImportError:
                     continue
 
+    @staticmethod
+    @lru_cache(maxsize=1024)
     def find_module(
-        self,
         modname: str,
-        module_parts: Sequence[str],
-        processed: list[str],
-        submodule_path: Sequence[str] | None,
+        module_parts: tuple[str, ...],
+        processed: tuple[str, ...],
+        submodule_path: tuple[str, ...] | None,
     ) -> ModuleSpec | None:
         try:
             file_type, filename, path = _search_zip(module_parts)
@@ -318,16 +297,22 @@ class ZipFinder(Finder):
             submodule_search_locations=path,
         )
 
+    def contribute_to_path(
+        self, spec: ModuleSpec, processed: list[str]
+    ) -> Sequence[str] | None:
+        return spec.submodule_search_locations
+
 
 class PathSpecFinder(Finder):
     """Finder based on importlib.machinery.PathFinder."""
 
+    @staticmethod
+    @lru_cache(maxsize=1024)
     def find_module(
-        self,
         modname: str,
-        module_parts: Sequence[str],
-        processed: list[str],
-        submodule_path: Sequence[str] | None,
+        module_parts: tuple[str, ...],
+        processed: tuple[str, ...],
+        submodule_path: tuple[str, ...] | None,
     ) -> ModuleSpec | None:
         spec = importlib.machinery.PathFinder.find_spec(modname, path=submodule_path)
         if spec is not None:
@@ -359,6 +344,7 @@ _SPEC_FINDERS = (
 )
 
 
+@lru_cache(maxsize=1024)
 def _is_setuptools_namespace(location: pathlib.Path) -> bool:
     try:
         with open(location / "__init__.py", "rb") as stream:
@@ -379,22 +365,12 @@ def _get_zipimporters() -> Iterator[tuple[str, zipimport.zipimporter]]:
 
 
 def _search_zip(
-    modpath: Sequence[str],
+    modpath: tuple[str, ...],
 ) -> tuple[Literal[ModuleType.PY_ZIPMODULE], str, str]:
     for filepath, importer in _get_zipimporters():
-        if PY310_PLUS:
-            found: Any = importer.find_spec(modpath[0])
-        else:
-            found = importer.find_module(modpath[0])
+        found = importer.find_spec(modpath[0])
         if found:
-            if PY310_PLUS:
-                if not importer.find_spec(os.path.sep.join(modpath)):
-                    raise ImportError(
-                        "No module named {} in {}/{}".format(
-                            ".".join(modpath[1:]), filepath, modpath
-                        )
-                    )
-            elif not importer.find_module(os.path.sep.join(modpath)):
+            if not importer.find_spec(os.path.sep.join(modpath)):
                 raise ImportError(
                     "No module named {} in {}/{}".format(
                         ".".join(modpath[1:]), filepath, modpath
@@ -411,18 +387,16 @@ def _search_zip(
 def _find_spec_with_path(
     search_path: Sequence[str],
     modname: str,
-    module_parts: list[str],
-    processed: list[str],
-    submodule_path: Sequence[str] | None,
+    module_parts: tuple[str, ...],
+    processed: tuple[str, ...],
+    submodule_path: tuple[str, ...] | None,
 ) -> tuple[Finder | _MetaPathFinder, ModuleSpec]:
     for finder in _SPEC_FINDERS:
         finder_instance = finder(search_path)
-        spec = finder_instance.find_module(
-            modname, module_parts, processed, submodule_path
-        )
-        if spec is None:
+        mod_spec = finder.find_module(modname, module_parts, processed, submodule_path)
+        if mod_spec is None:
             continue
-        return finder_instance, spec
+        return finder_instance, mod_spec
 
     # Support for custom finders
     for meta_finder in sys.meta_path:
@@ -485,32 +459,38 @@ def find_spec(modpath: Iterable[str], path: Iterable[str] | None = None) -> Modu
 
 
 @lru_cache(maxsize=1024)
-def _find_spec(module_path: tuple, path: tuple) -> ModuleSpec:
+def _find_spec(
+    module_path: tuple[str, ...], path: tuple[str, ...] | None
+) -> ModuleSpec:
     _path = path or sys.path
 
     # Need a copy for not mutating the argument.
     modpath = list(module_path)
 
-    submodule_path = None
-    module_parts = modpath[:]
+    search_paths = None
     processed: list[str] = []
 
     while modpath:
         modname = modpath.pop(0)
+
+        submodule_path = search_paths or path
+        if submodule_path is not None:
+            submodule_path = tuple(submodule_path)
+
         finder, spec = _find_spec_with_path(
-            _path, modname, module_parts, processed, submodule_path or path
+            _path, modname, module_path, tuple(processed), submodule_path
         )
         processed.append(modname)
         if modpath:
             if isinstance(finder, Finder):
-                submodule_path = finder.contribute_to_path(spec, processed)
-            # If modname is a package from an editable install, update submodule_path
+                search_paths = finder.contribute_to_path(spec, processed)
+            # If modname is a package from an editable install, update search_paths
             # so that the next module in the path will be found inside of it using importlib.
             # Existence of __name__ is guaranteed by _find_spec_with_path.
             elif finder.__name__ in _EditableFinderClasses:  # type: ignore[attr-defined]
-                submodule_path = spec.submodule_search_locations
+                search_paths = spec.submodule_search_locations
 
         if spec.type == ModuleType.PKG_DIRECTORY:
-            spec = spec._replace(submodule_search_locations=submodule_path)
+            spec = spec._replace(submodule_search_locations=search_paths)
 
     return spec
